@@ -12,6 +12,7 @@ use crate::{
     err::ConfigError,
     impl_cache,
     key::{CacheString, ConfigKey, PartialKeyIter},
+    macros::{cfg_log, impl_default},
     source::{
         cargo::Cargo, environment::PrefixEnvironment, memory::HashSource, register_by_ext,
         register_files, ConfigSource, SourceOption,
@@ -74,10 +75,10 @@ impl<'a> ConfigContext<'a> {
         val: &str,
         history: &mut HashSet<String>,
     ) -> Result<(bool, Option<ConfigValue<'a>>), ConfigError> {
+        let pat: &[_] = &['$', '\\', '}'];
         CacheValue::with_key(move |cv| {
             cv.clear();
             let mut value = val;
-            let pat: &[_] = &['$', '\\', '}'];
             let mut flag = true;
             while let Some(pos) = value.find(pat) {
                 flag = false;
@@ -115,7 +116,7 @@ impl<'a> ConfigContext<'a> {
                         let v = &(cv.buf.as_str())[last..];
                         let (key, def) = match v.find(':') {
                             Some(pos) => (&v[..pos], Some(&v[pos + 1..])),
-                            _ => (&v[..], None),
+                            _ => (v, None),
                         };
                         if !history.insert(key.to_string()) {
                             return Err(ConfigError::ConfigRecursiveError(current_key.to_string()));
@@ -161,7 +162,7 @@ impl<'a> ConfigContext<'a> {
         default_value: Option<ConfigValue<'_>>,
         history: &mut HashSet<String>,
     ) -> Result<T, ConfigError> {
-        self.key.push(partial_key);
+        let mark = self.key.push(partial_key);
         let value = match self.source.get_value(&self.key).or(default_value) {
             Some(ConfigValue::StrRef(s)) => {
                 match Self::parse_placeholder(self.source, &self.key, s, history)? {
@@ -181,7 +182,7 @@ impl<'a> ConfigContext<'a> {
         };
 
         let v = T::from_config(self, value);
-        self.key.pop();
+        self.key.pop(mark);
         v
     }
 
@@ -201,6 +202,11 @@ impl<'a> ConfigContext<'a> {
         self.key.to_string()
     }
 
+    #[allow(dead_code)]
+    pub(crate) fn current_key_str(&self) -> &str {
+        self.key.as_str()
+    }
+
     #[inline]
     pub(crate) fn type_mismatch<T: Any>(&self, value: &ConfigValue<'_>) -> ConfigError {
         let tp = match value {
@@ -242,6 +248,8 @@ pub struct Configuration {
     loaders: Vec<Box<dyn ConfigSource + Send + 'static>>,
 }
 
+impl_default!(Configuration);
+
 impl Configuration {
     /// Create an empty [`Configuration`].
     ///
@@ -321,7 +329,14 @@ impl Configuration {
             return Err(ConfigError::TooManyInstances(self.max));
         }
         let loader = CacheConfigSource::new(loader);
-        loader.load(&mut self.source.prefixed())?;
+        let builder = &mut self.source.prefixed();
+        loader.load(builder)?;
+        cfg_log!(
+            log::Level::Debug,
+            "Config source {}:{} registered.",
+            self.loaders.len() + 1,
+            loader.name()
+        );
         self.loaders.push(Box::new(loader));
         Ok(self)
     }
@@ -341,6 +356,7 @@ impl Configuration {
                 i.load(c)?;
             }
             self.source.refs.refresh(&s)?;
+            cfg_log!(log::Level::Info, "Configuration refreshed");
         }
         Ok((refreshed, s))
     }
@@ -402,6 +418,7 @@ impl Configuration {
             memory: HashSource::new("fixed:FromProgram/CommandLineArgs"),
             cargo: None,
             prefix: None,
+            init: None,
         }
     }
 
@@ -412,11 +429,12 @@ impl Configuration {
 }
 
 /// Predefined Configuration Builder. See [init](struct.PredefinedConfigurationBuilder.html#method.init) for details.
-#[allow(missing_debug_implementations)]
+#[allow(clippy::type_complexity, missing_debug_implementations)]
 pub struct PredefinedConfigurationBuilder {
     memory: HashSource,
     cargo: Option<Cargo>,
     prefix: Option<String>,
+    init: Option<Box<dyn FnOnce(&Configuration) -> Result<(), ConfigError> + 'static>>,
 }
 
 impl PredefinedConfigurationBuilder {
@@ -475,6 +493,15 @@ impl PredefinedConfigurationBuilder {
         self
     }
 
+    /// Set init func, which will be run after env source loaded.
+    pub fn set_init<F: FnOnce(&Configuration) -> Result<(), ConfigError> + 'static>(
+        mut self,
+        f: F,
+    ) -> Self {
+        self.init = Some(Box::new(f));
+        self
+    }
+
     /// Initialize configuration by multiple predefined sources.
     ///
     /// ## Predefined Sources.
@@ -521,9 +548,14 @@ impl PredefinedConfigurationBuilder {
             .prefix
             .or_else(|| config.get::<Option<String>>("env.prefix").ok().flatten())
             .or_else(|| var("CFG_ENV_PREFIX").ok())
-            .unwrap_or("CFG".to_owned());
+            .unwrap_or_else(|| "CFG".to_owned());
         config = config.register_prefix_env(&prefix)?;
 
+        if let Some(init) = self.init {
+            (init)(&config)?;
+            cfg_log!(log::Level::Info, "Early initialization completed.");
+        }
+
         // Layer 4, profile file.
         let app = config.get_predefined::<AppConfig>()?;
         let mut path = PathBuf::new();
@@ -540,6 +572,10 @@ impl PredefinedConfigurationBuilder {
         path.push(app.name);
         config = register_files(config, &option, path, false)?;
 
+        cfg_log!(
+            log::Level::Info,
+            "Predefined configuration initialization completed."
+        );
         Ok(config)
     }
 }
